@@ -142,7 +142,7 @@ class AltimeterNeptuneClient:
             graph_metadata = self._get_latest_graph_metadata(name=graph_name)
             graph_uris_load_times[graph_metadata.uri] = graph_metadata.end_time
         finalized_query = finalize_query(query, graph_uris=list(graph_uris_load_times.keys()))
-        query_result_set = self._run_query_helper(finalized_query)
+        query_result_set = self.run_raw_query(finalized_query)
         return QueryResult(graph_uris_load_times, query_result_set)
 
     def load_graph(self, bucket: str, key: str, load_iam_role_arn: str) -> GraphMetadata:
@@ -300,6 +300,23 @@ class AltimeterNeptuneClient:
                 (f"Error updating graph {META_GRAPH_NAME} " f"with {update_stmt} : {resp.text}")
             )
 
+    def get_graph_uris(self, name: str) -> List[str]:
+        """Return all graph uris regardless of whether they have corresponding metadata entries
+
+        Args:
+            name: graph name
+
+        Returns:
+            list of graph uris
+        """
+        query = "SELECT ?graph_uri WHERE { GRAPH ?graph_uri { } }"
+        results = self.run_raw_query(query=query)
+        results_list = results.to_list()
+        all_graph_uris = [result["graph_uri"] for result in results_list]
+        graph_prefix = f"{GRAPH_BASE_URI}/{name}/"
+        graph_uris = [uri for uri in all_graph_uris if uri.startswith(graph_prefix)]
+        return graph_uris
+
     def get_graph_metadatas(self, name: str, version: Optional[str] = None) -> List[GraphMetadata]:
         """Return all graph metadatas for a given name/version. These represent fully loaded
         graphs in the Neptune database.
@@ -336,7 +353,7 @@ class AltimeterNeptuneClient:
                 f"                         <alti:end_time> ?end_time }}\n"
                 f"ORDER BY DESC(?end_time)\n"
             )
-        results = self._run_query_helper(query=get_graph_metadatas_query)
+        results = self.run_raw_query(query=get_graph_metadatas_query)
         results_list = results.to_list()
         graph_metadatas: List[GraphMetadata] = []
         for result in results_list:
@@ -350,24 +367,6 @@ class AltimeterNeptuneClient:
             graph_metadatas.append(graph_metadata)
         return graph_metadatas
 
-    def clear_graph(self, graph_uri: str) -> None:
-        """Clear a graph by name in Neptune
-
-        Args:
-            graph_uri: uri of graph to clear
-
-        Raises:
-            NeptuneClearGraphException if an error occurred during graph clearing.
-        """
-        auth = self._get_auth()
-        neptune_sparql_url = self._neptune_endpoint.get_sparql_endpoint()
-        update_stmt = f"clear graph <{graph_uri}>"
-        resp = requests.post(neptune_sparql_url, data={"update": update_stmt}, auth=auth)
-        if resp.status_code != 200:
-            raise NeptuneClearGraphException(
-                (f"Error clearing graph {graph_uri} " f"with {update_stmt} : {resp.text}")
-            )
-
     def _get_latest_graph_metadata(self, name: str, version: Optional[str] = None) -> GraphMetadata:
         """Return a GraphMetadata object representing the most recently successfully loaded graph
         for a given name / version.
@@ -410,7 +409,7 @@ class AltimeterNeptuneClient:
                 f"ORDER BY DESC(?end_time)\n"
                 f"LIMIT 1"
             )
-        results = self._run_query_helper(query=get_graph_metadatas_query)
+        results = self.run_raw_query(query=get_graph_metadatas_query)
         results_list = results.to_list()
         if not results_list:
             raise NeptuneNoGraphsFoundException(f"No graphs found for graph name '{name}'")
@@ -439,35 +438,40 @@ class AltimeterNeptuneClient:
             end_time=latest_end_time,
         )
 
-    def clear_old_graph_metadata(self, name: str, max_age_min: int) -> None:
-        """Remove all entries in the meta graph older than max_age_min minutes for a given name.
+    def clear_registered_graph(self, name: str, uri: str) -> None:
+        """Remove data and metadata for a graph by uri
 
         Args:
             name: graph name
-            max_age_min: clear graphs older than this number (in min)
+            uri: graph uri
 
         Raises:
-            NeptuneUpdateGraphException if an error occurred during metadata graph update
+            NeptuneUpdateGraphException if an error occurred during clearing
         """
-        now = int(datetime.now().timestamp())
-        oldest_acceptable_graph_scan_time = now - max_age_min * 60
+        # clear metadata first such that clients will not use this graph if
+        # data clear fails
+        self.clear_graph_metadata(name=name, uri=uri)
+        # then clear data
+        self.clear_graph_data(uri=uri)
+
+    def clear_graph_metadata(self, name: str, uri: str) -> None:
+        """Clear a graph metadata entry"""
         auth = self._get_auth()
         neptune_sparql_url = self._neptune_endpoint.get_sparql_endpoint()
         delete_stmt = (
             f"WITH <{META_GRAPH_NAME}>\n"
             f"DELETE\n"
-            f"  {{ ?graph <alti:uri>         ?uri ;\n"
+            f'  {{ ?graph <alti:uri>         "{uri}" ;\n'
             f'            <alti:name>        "{name}" ;\n'
             f"            <alti:version>     ?version ;\n"
             f"            <alti:start_time>  ?start_time ;\n"
             f"            <alti:end_time>    ?end_time }}\n"
             f"WHERE\n"
-            f"  {{ ?graph <alti:uri>         ?uri ;\n"
+            f'  {{ ?graph <alti:uri>         "{uri}" ;\n'
             f'            <alti:name>        "{name}" ;\n'
             f"            <alti:version>     ?version ;\n"
             f"            <alti:start_time>  ?start_time ;\n"
-            f"            <alti:end_time>    ?end_time .\n"
-            f"    FILTER ( xsd:integer(?end_time) < {oldest_acceptable_graph_scan_time} ) }}"
+            f"            <alti:end_time>    ?end_time }}\n"
         )
         resp = requests.post(neptune_sparql_url, data={"update": delete_stmt}, auth=auth)
         if resp.status_code != 200:
@@ -475,9 +479,20 @@ class AltimeterNeptuneClient:
                 (f"Error updating graph {META_GRAPH_NAME} " f"with {delete_stmt} : {resp.text}")
             )
 
-    def _run_query_helper(self, query: str) -> QueryResultSet:
+    def clear_graph_data(self, uri: str) -> None:
+        """Clear a graph in Neptune"""
+        auth = self._get_auth()
+        neptune_sparql_url = self._neptune_endpoint.get_sparql_endpoint()
+        update_stmt = f"clear graph <{uri}>"
+        resp = requests.post(neptune_sparql_url, data={"update": update_stmt}, auth=auth)
+        if resp.status_code != 200:
+            raise NeptuneClearGraphException(
+                (f"Error clearing graph {uri} " f"with {update_stmt} : {resp.text}")
+            )
+
+    def run_raw_query(self, query: str) -> QueryResultSet:
         """Run a query against a neptune instance, return a dict of results. Generally this
-        should
+        should be called from `run_query`
 
         Args:
             query: complete query to run
